@@ -72,7 +72,9 @@ pub use error::RadError;
 pub use basic::MacroType;
 pub use processor::Processor;
 pub use auth::AuthType;
-pub use models::{CommentType, RadResult};
+#[cfg(feature = "hook")]
+pub use hookmap::HookType;
+pub use models::{CommentType, RadResult, DiffOption};
 
 // Optional
 
